.. rst-class:: hide-header

Welcome to Extliner documentation!
==================================

.. image:: https://pepy.tech/badge/extliner
   :alt: Download badge
   :target: https://pepy.tech/project/extliner

Extliner is a lightweight CLI tool for analyzing and counting lines of code in your projects efficiently.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   cli_reference
   contributing
   changelog
